mercurial/merge.py
changeset 33146 7017567ebdf2
parent 33095 9fc880dff5f3
child 33283 634b259079c5
--- a/mercurial/merge.py	Tue Jun 27 01:36:20 2017 +0200
+++ b/mercurial/merge.py	Tue Jun 27 01:40:34 2017 +0200
@@ -28,7 +28,7 @@
     error,
     filemerge,
     match as matchmod,
-    obsolete,
+    obsutil,
     pycompat,
     scmutil,
     subrepo,
@@ -1588,8 +1588,8 @@
                 dirty = wc.dirty(missing=True)
                 if dirty:
                     # Branching is a bit strange to ensure we do the minimal
-                    # amount of call to obsolete.foreground.
-                    foreground = obsolete.foreground(repo, [p1.node()])
+                    # amount of call to obsutil.foreground.
+                    foreground = obsutil.foreground(repo, [p1.node()])
                     # note: the <node> variable contains a random identifier
                     if repo[node].node() in foreground:
                         pass # allow updating to successors